@@ -1,8 +1,9 @@
-/* Copyright 2001-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -52,12 +53,12 @@ static void modperl_bucket_sv_destroy(void *data)
     dTHXa(svbucket->perl);
 
     if (!apr_bucket_shared_destroy(svbucket)) {
-        MP_TRACE_f(MP_FUNC, "bucket refcnt=%d\n",
+        MP_TRACE_f(MP_FUNC, "bucket refcnt=%d",
                    ((apr_bucket_refcount *)svbucket)->refcount);
         return;
     }
 
-    MP_TRACE_f(MP_FUNC, "sv=0x%lx, refcnt=%d\n",
+    MP_TRACE_f(MP_FUNC, "sv=0x%lx, refcnt=%d",
                (unsigned long)svbucket->sv, SvREFCNT(svbucket->sv));
 
     SvREFCNT_dec(svbucket->sv);
@@ -65,7 +66,7 @@ static void modperl_bucket_sv_destroy(void *data)
     apr_bucket_free(svbucket);
 }
 
-static 
+static
 apr_status_t modperl_bucket_sv_setaside(apr_bucket *bucket, apr_pool_t *pool)
 {
     modperl_bucket_sv_t *svbucket = bucket->data;
@@ -110,7 +111,7 @@ static apr_bucket *modperl_bucket_sv_make(pTHX_
                                           apr_off_t offset,
                                           apr_size_t len)
 {
-    modperl_bucket_sv_t *svbucket; 
+    modperl_bucket_sv_t *svbucket;
 
     svbucket = apr_bucket_alloc(sizeof(*svbucket), bucket->list);
 
@@ -138,14 +139,14 @@ static apr_bucket *modperl_bucket_sv_make(pTHX_
         (void)SvREFCNT_inc(svbucket->sv);
     }
 
-    MP_TRACE_f(MP_FUNC, "sv=0x%lx, refcnt=%d\n",
+    MP_TRACE_f(MP_FUNC, "sv=0x%lx, refcnt=%d",
                (unsigned long)svbucket->sv, SvREFCNT(svbucket->sv));
 
     bucket->type = &modperl_bucket_sv_type;
     return bucket;
 }
 
-apr_bucket *modperl_bucket_sv_create(pTHX_ apr_bucket_alloc_t *list, SV *sv, 
+apr_bucket *modperl_bucket_sv_create(pTHX_ apr_bucket_alloc_t *list, SV *sv,
                                      apr_off_t offset, apr_size_t len)
 {
     apr_bucket *bucket;
