@@ -7,13 +7,15 @@ package TestFilter::both_str_req_proxy;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::Filter ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::Filter ();
 
 use Apache::TestTrace;
 
-use Apache::Const -compile => qw(OK M_POST);
+use TestCommon::Utils ();
+
+use Apache2::Const -compile => qw(OK M_POST);
 
 sub in_filter {
     my $filter = shift;
@@ -24,7 +26,7 @@ sub in_filter {
         $filter->print(lc $buffer);
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub out_filter {
@@ -37,7 +39,7 @@ sub out_filter {
         $filter->print($buffer);
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub handler {
@@ -47,11 +49,11 @@ sub handler {
 
     $r->content_type('text/plain');
 
-    if ($r->method_number == Apache::M_POST) {
-        $r->print(ModPerl::Test::read_post($r));
+    if ($r->method_number == Apache2::Const::M_POST) {
+        $r->print(TestCommon::Utils::read_post($r));
     }
 
-    return Apache::OK;
+    return Apache2::Const::OK;
 }
 
 1;
@@ -67,7 +69,6 @@ __DATA__
         </Proxy>
 
         ProxyRequests Off
-        RewriteEngine On
 
         ProxyPass    /TestFilter__both_str_req_proxy/ \
         http://@servername@:@port@/TestFilter__both_str_req_proxy_content/
