@@ -14,7 +14,7 @@ package TestFilter::in_str_consume;
 # currently if the streaming filter doesn't print anything, the
 # upstream filter gets an empty brigade brigade (easily verified with
 # the snooping debug filter). Of course if the filter returns
-# Apache::DECLINED the unconsumed data will be passed to upstream filter
+# Apache2::Const::DECLINED the unconsumed data will be passed to upstream filter
 #
 # However this filter has a problem. Since it doesn't consume all the
 # data, the client is left with un-read data, and when the response is
@@ -54,13 +54,15 @@ package TestFilter::in_str_consume;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::Filter ();
+use Apache2::Filter ();
 use Apache::TestTrace;
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => qw(OK M_POST);
+use TestCommon::Utils ();
+
+use Apache2::Const -compile => qw(OK M_POST);
 
 use constant READ_BYTES_TOTAL => 105;
 use constant READ_BYTES_FIRST => 23;
@@ -113,7 +115,7 @@ sub handler {
         # if we don't need to have it as a whole chunk
     }
 
-    return Apache::OK;
+    return Apache2::Const::OK;
 }
 
 sub response {
@@ -121,8 +123,8 @@ sub response {
 
     $r->content_type('text/plain');
 
-    if ($r->method_number == Apache::M_POST) {
-        my $data = ModPerl::Test::read_post($r);
+    if ($r->method_number == Apache2::Const::M_POST) {
+        my $data = TestCommon::Utils::read_post($r);
 
         # tell Apache to get rid of the rest of the request body
         # if we don't a client will get a broken pipe and may fail to
@@ -134,13 +136,13 @@ sub response {
         $r->print($len);
     }
 
-    return Apache::OK;
+    return Apache2::Const::OK;
 }
 1;
 __DATA__
 SetHandler modperl
 PerlModule          TestFilter::in_str_consume
 PerlResponseHandler TestFilter::in_str_consume::response
-#PerlInputFilterHandler  ModPerl::TestFilterDebug::snoop_request
+#PerlInputFilterHandler  TestCommon::FilterDebug::snoop_request
 PerlInputFilterHandler  TestFilter::in_str_consume::handler
-#PerlInputFilterHandler  ModPerl::TestFilterDebug::snoop_request
+#PerlInputFilterHandler  TestCommon::FilterDebug::snoop_request
