@@ -6,12 +6,14 @@ use warnings FATAL => 'all';
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Filter ();
+use Apache2::Filter ();
 
-use Apache::Const -compile => qw(OK DECLINED M_POST);
+use TestCommon::Utils ();
+
+use Apache2::Const -compile => qw(OK DECLINED M_POST);
 
 # make sure that if the input filter returns DECLINED without
 # reading/printing data the data flow is not broken
@@ -27,7 +29,7 @@ sub handler {
       $filter->r->notes->set(invoked => $ctx->{invoked});
       #warn "filter was invoked $ctx->{invoked} times\n";
 
-      return Apache::DECLINED;
+      return Apache2::Const::DECLINED;
 }
 
 sub response {
@@ -37,9 +39,9 @@ sub response {
 
     $r->content_type('text/plain');
 
-    if ($r->method_number == Apache::M_POST) {
+    if ($r->method_number == Apache2::Const::M_POST) {
         # consume the data so the input filter is invoked
-        my $data = ModPerl::Test::read_post($r);
+        my $data = TestCommon::Utils::read_post($r);
         ok t_cmp(length $data, 20000, "the request body received ok");
     }
 
@@ -52,7 +54,7 @@ sub response {
     my $invoked = $r->notes->get('invoked') || 0;
     ok $invoked > 1;
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 1;
 __DATA__
