@@ -3,11 +3,13 @@ package TestAPI::internal_redirect;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::SubRequest ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::SubRequest ();
 
-use Apache::Const -compile => 'OK';
+use Apache::TestTrace;
+
+use Apache2::Const -compile => 'OK';
 
 sub modperl {
     my $r = shift;
@@ -16,15 +18,17 @@ sub modperl {
     if ($args{main}) {
         # sub-req
         $r->content_type('text/plain');
+        debug "modperl: sub-req: response";
         $r->print("internal redirect: $args{main} => modperl");
     }
     else {
         # main-req
         my $redirect_uri = $args{uri};
+        debug "modperl: main-req => $redirect_uri?main=modperl";
         $r->internal_redirect("$redirect_uri?main=modperl");
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 sub perl_script {
@@ -34,15 +38,17 @@ sub perl_script {
     if ($args{main}) {
         # sub-req
         $r->content_type('text/plain');
+        debug "perl-script: sub-req: response";
         print "internal redirect: $args{main} => perl-script";
     }
     else {
         # main-req
         my $redirect_uri = $args{uri};
+        debug "perl-script: main-req => $redirect_uri?main=perl-script";
         $r->internal_redirect("$redirect_uri?main=perl-script");
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 1;
 __DATA__
