@@ -5,14 +5,14 @@ package TestAPI::sub_request;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::SubRequest ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::SubRequest ();
 
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK SERVER_ERROR);
+use Apache2::Const -compile => qw(OK SERVER_ERROR);
 
 my $uri = '/' . Apache::TestRequest::module2path(__PACKAGE__);
 
@@ -20,24 +20,24 @@ sub handler {
     my $r = shift;
 
     my $args = $r->args || '';
-    return Apache::SERVER_ERROR if $args eq 'subreq';
+    return Apache2::Const::SERVER_ERROR if $args eq 'subreq';
 
     plan $r, tests => 4;
 
     my $subr = $r->lookup_uri("$uri?subreq");
-    ok $subr->isa('Apache::SubRequest');
+    ok $subr->isa('Apache2::SubRequest');
 
     ok t_cmp $subr->uri, $uri, "uri";
 
     my $rc = $subr->run;
-    ok $rc, Apache::SERVER_ERROR, "rc";
+    ok t_cmp $rc, Apache2::Const::SERVER_ERROR, "rc";
 
-    # test an explictit DESTROY (which happens automatically on the
+    # test an explicit DESTROY (which happens automatically on the
     # scope exit)
-    $subr->DESTROY;
+    undef $subr;
     ok 1;
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
