@@ -8,11 +8,11 @@ use warnings  FATAL => 'all';
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Connection ();
-use Apache::RequestRec ();
+use Apache2::Connection ();
+use Apache2::RequestRec ();
 use APR::SockAddr ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -23,14 +23,14 @@ sub handler {
     my $local  = $c->local_addr;
     my $remote = $c->remote_addr;
 
-    ok t_cmp($c->local_ip,  $local->ip_get,  "local ip");
-    ok t_cmp($c->remote_ip, $remote->ip_get, "remote ip");
+    ok t_cmp($local->ip_get,  $c->local_ip,  "local ip");
+    ok t_cmp($remote->ip_get, $c->remote_ip, "remote ip");
 
     $r->subprocess_env;
-    ok t_cmp($ENV{SERVER_PORT}, $local->port,  "local port");
-    ok t_cmp($ENV{REMOTE_PORT}, $remote->port, "remote port");
+    ok t_cmp($local->port,  $ENV{SERVER_PORT}, "local port");
+    ok t_cmp($remote->port, $ENV{REMOTE_PORT}, "remote port");
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
