@@ -3,10 +3,10 @@ package TestApache::cgihandler;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 use APR::Table ();
 
-use Apache::Const -compile => qw(OK M_POST);
+use Apache2::Const -compile => qw(OK M_POST);
 
 #test the 1.x style perl-script handler
 
@@ -15,13 +15,13 @@ sub handler {
 
     $ENV{FOO} = 2;
 
-    if ($r->method_number == Apache::M_POST) {
-        my $ct = $r->headers_in->get('content-length');
+    if ($r->method_number == Apache2::Const::M_POST) {
+        my $cl = $r->headers_in->get('content-length');
         my $buff;
 #XXX: working around a bug in ithreads Perl
 #that would cause modules/cgi #3 to fail
-#        read STDIN, $buff, $ct;
-        read 'STDIN', $buff, $ct;
+#        read STDIN, $buff, $cl;
+        read 'STDIN', $buff, $cl;
         print $buff;
     }
     else {
@@ -35,12 +35,11 @@ sub handler {
         print "ok $foo\n";
     }
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
 __END__
 SetHandler perl-script
-<IfDefine PERL_ITHREADS>
-    PerlInterpScope handler
-</IfDefine>
+PerlResponseHandler TestApache::cgihandler
+
