@@ -7,21 +7,20 @@ package TestModperl::print_utf8_2;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestIO ();
-use Apache::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::RequestRec ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
 
     $r->content_type('text/plain; charset=UTF-8');
 
-    # must be non-$r->print(), so we go through the tied STDOUT
     # \x{263A} == :-)
     $r->print("\$r->print() just works \x{263A}");
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
