@@ -1,9 +1,12 @@
 package TestModperl::request_rec_tie_api;
 
+# this test is relevant only when the tied STDIN/STDOUT are used (when
+# $Config{useperlio} is not defined.)
+
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestIO ();
+use Apache2::RequestIO ();
 
 use Apache::Test;
 use Apache::TestUtil;
@@ -11,15 +14,19 @@ use Apache::TestConfig;
 
 use File::Spec::Functions qw(catfile catdir);
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
+
+use Config;
 
 sub handler {
     my $r = shift;
 
-    require Apache::Build;
+    require Apache2::Build;
     my @todo;
-    push @todo, 1 if Apache::Build::AIX();
-    plan $r, tests => 3, todo => \@todo;
+    push @todo, 1 if Apache2::Build::AIX();
+    plan $r, tests => 3, todo => \@todo,
+        need { "perl $]: PerlIO is used instead of TIEd IO"
+                   => !($] >= 5.008 && $Config{useperlio}) };
 
     # XXX: on AIX 4.3.3 we get:
     #                     STDIN STDOUT STDERR
@@ -36,7 +43,7 @@ sub handler {
 
         # test OPEN
         my $received = open STDOUT, ">", $file or die "Can't open $file: $!";
-        ok t_cmp(1, $received, "OPEN");
+        ok t_cmp($received, 1, "OPEN");
 
         # test CLOSE, which is a noop
         ok $r->CLOSE;
@@ -54,7 +61,7 @@ sub handler {
         unlink $file;
     }
 
-    return Apache::OK;
+    return Apache2::Const::OK;
 }
 
 1;
