@@ -24,7 +24,7 @@ SV *mpxs_apr_ipsubnet_create(pTHX_ SV *classname, SV *p_sv,
     SV *ipsub_sv;
     MP_RUN_CROAK(apr_ipsubnet_create(&ipsub, ipstr, mask_or_numbits, p),
                  "APR::IpSubnet::new");
-    ipsub_sv = sv_setref_pv(NEWSV(0, 0), "APR::IpSubnet", (void*)ipsub);
+    ipsub_sv = sv_setref_pv(newSV(0), "APR::IpSubnet", (void*)ipsub);
     mpxs_add_pool_magic(ipsub_sv, p_sv);
     return ipsub_sv;
 }
