@@ -121,17 +121,17 @@
       * the object is generated by modperl_hash_tie, so under 5.8+
       * need to use sv_magicext, since sv_magicext does only one magic
       * of the same type at 5.8+ */
-#define mpxs_add_pool_magic_doit(obj, pool_obj)                         \
-    sv_magicext(SvRV(obj), pool_obj, PERL_MAGIC_ext, NULL, Nullch, -1)
+#define mpxs_add_pool_magic_doit(obj, pool_obj)                               \
+    sv_magicext(SvRV(obj), pool_obj, PERL_MAGIC_ext, NULL, (char *)NULL, -1)
 #else
-#define mpxs_add_pool_magic_doit(obj, pool_obj)                         \
-    sv_magic(SvRV(obj), pool_obj, PERL_MAGIC_ext, Nullch, -1)
+#define mpxs_add_pool_magic_doit(obj, pool_obj)                               \
+    sv_magic(SvRV(obj), pool_obj, PERL_MAGIC_ext, (char *)NULL, -1)
 #endif
 
 /* add dependency magic only for custom pools.  there are all kind of
  * complications when more than one magic of the same type(in this
  * case PERL_MAGIC_ext is added), luckily most of the PERL_MAGIC_ext
- * magic used by modperl-core, uses Nullsv as mg->mg_obj, therefore
+ * magic used by modperl-core, uses (SV *)NULL as mg->mg_obj, therefore
  * the following code tries to workaround the multiple magic issue, by
  * simply hanging the pool object into the unused slot, incrementing
  * its refcnt just like sv_magic does internally. In case we ever hit
@@ -142,7 +142,7 @@
     if (mpxs_pool_is_custom(SvRV(pool_obj))) {                     \
         MAGIC *mg = mg_find(SvRV(obj), PERL_MAGIC_ext);            \
         if (mg) {                                                  \
-            if (mg->mg_obj == Nullsv) {                            \
+            if (mg->mg_obj == (SV *)NULL) {                        \
                 mg->mg_obj = SvREFCNT_inc(SvRV(pool_obj));         \
                 mg->mg_flags |= MGf_REFCOUNTED;                    \
             }                                                      \
